@@ -36,11 +36,11 @@ import java.util.concurrent.TimeUnit;
 import org.apache.jackrabbit.aws.ext.S3Constants;
 import org.apache.jackrabbit.aws.ext.S3RequestDecorator;
 import org.apache.jackrabbit.aws.ext.Utils;
+import org.apache.jackrabbit.core.data.AbstractBackend;
 import org.apache.jackrabbit.core.data.AsyncTouchCallback;
 import org.apache.jackrabbit.core.data.AsyncTouchResult;
 import org.apache.jackrabbit.core.data.AsyncUploadCallback;
 import org.apache.jackrabbit.core.data.AsyncUploadResult;
-import org.apache.jackrabbit.core.data.Backend;
 import org.apache.jackrabbit.core.data.CachingDataStore;
 import org.apache.jackrabbit.core.data.DataIdentifier;
 import org.apache.jackrabbit.core.data.DataStoreException;
@@ -52,6 +52,7 @@ import com.amazonaws.AmazonClientException;
 import com.amazonaws.AmazonServiceException;
 import com.amazonaws.event.ProgressEvent;
 import com.amazonaws.event.ProgressListener;
+import com.amazonaws.regions.Regions;
 import com.amazonaws.services.s3.AmazonS3Client;
 import com.amazonaws.services.s3.model.CopyObjectRequest;
 import com.amazonaws.services.s3.model.DeleteObjectsRequest;
@@ -61,15 +62,17 @@ import com.amazonaws.services.s3.model.ObjectMetadata;
 import com.amazonaws.services.s3.model.PutObjectRequest;
 import com.amazonaws.services.s3.model.Region;
 import com.amazonaws.services.s3.model.S3Object;
+import com.amazonaws.services.s3.model.S3ObjectInputStream;
 import com.amazonaws.services.s3.model.S3ObjectSummary;
 import com.amazonaws.services.s3.transfer.Copy;
 import com.amazonaws.services.s3.transfer.TransferManager;
 import com.amazonaws.services.s3.transfer.Upload;
+import com.amazonaws.util.StringUtils;
 
 /**
  * A data store backend that stores data on Amazon S3.
  */
-public class S3Backend implements Backend {
+public class S3Backend extends AbstractBackend {
 
     /**
      * Logger instance.
@@ -84,13 +87,9 @@ public class S3Backend implements Backend {
 
     private TransferManager tmx;
 
-    private CachingDataStore store;
-
     private Properties properties;
 
     private Date startTime;
-    
-    private ThreadPoolExecutor asyncWriteExecuter;
 
     private S3RequestDecorator s3ReqDecorator;
 
@@ -101,6 +100,7 @@ public class S3Backend implements Backend {
     @Override
     public void init(CachingDataStore store, String homeDir, String config)
             throws DataStoreException {
+        super.init(store, homeDir, config);
         Properties initProps = null;
         //Check is configuration is already provided. That takes precedence
         //over config provided via file based config
@@ -130,7 +130,7 @@ public class S3Backend implements Backend {
             Thread.currentThread().setContextClassLoader(
                 getClass().getClassLoader());
             LOG.debug("init");
-            this.store = store;
+            setDataStore(store);
             s3ReqDecorator = new S3RequestDecorator(prop);
 
             s3service = Utils.openService(prop);
@@ -139,12 +139,24 @@ public class S3Backend implements Backend {
             }
             String region = prop.getProperty(S3Constants.S3_REGION);
             Region s3Region = null;
-            if (Utils.DEFAULT_AWS_BUCKET_REGION.equals(region)) {
-                s3Region =  Region.US_Standard;
-            } else if (Region.EU_Ireland.toString().equals(region)) {
-                s3Region = Region.EU_Ireland;
+            if (StringUtils.isNullOrEmpty(region)) {
+                com.amazonaws.regions.Region ec2Region = Regions.getCurrentRegion();
+                if (ec2Region != null) {
+                    s3Region = Region.fromValue(ec2Region.getName());
+                } else {
+                    throw new AmazonClientException(
+                        "parameter ["
+                            + S3Constants.S3_REGION
+                            + "] not configured and cannot be derived from environment");
+                }
             } else {
-                s3Region = Region.fromValue(region);
+                if (Utils.DEFAULT_AWS_BUCKET_REGION.equals(region)) {
+                    s3Region = Region.US_Standard;
+                } else if (Region.EU_Ireland.toString().equals(region)) {
+                    s3Region = Region.EU_Ireland;
+                } else {
+                    s3Region = Region.fromValue(region);
+                }
             }
             
             if (!s3service.doesBucketExist(bucket)) {
@@ -170,9 +182,7 @@ public class S3Backend implements Backend {
                 asyncWritePoolSize = Integer.parseInt(maxConnsStr)
                     - writeThreads;
             }
-            
-            asyncWriteExecuter = (ThreadPoolExecutor) Executors.newFixedThreadPool(
-                asyncWritePoolSize, new NamedThreadFactory("s3-write-worker"));
+            setAsyncWritePoolSize(asyncWritePoolSize);
             String renameKeyProp = prop.getProperty(S3Constants.S3_RENAME_KEYS);
             boolean renameKeyBool = (renameKeyProp == null || "".equals(renameKeyProp))
                     ? false
@@ -212,7 +222,7 @@ public class S3Backend implements Backend {
             throw new IllegalArgumentException(
                 "callback parameter cannot be null in asyncUpload");
         }
-        asyncWriteExecuter.execute(new AsyncUploadJob(identifier, file,
+        getAsyncWriteExecutor().execute(new AsyncUploadJob(identifier, file,
             callback));
     }
 
@@ -230,7 +240,7 @@ public class S3Backend implements Backend {
             ObjectMetadata objectMetaData = s3service.getObjectMetadata(bucket,
                 key);
             if (objectMetaData != null) {
-                LOG.debug("exists [{}]: [true] took [{}] ms.",
+                LOG.trace("exists [{}]: [true] took [{}] ms.",
                     identifier, (System.currentTimeMillis() - start) );
                 return true;
             }
@@ -313,7 +323,7 @@ public class S3Backend implements Backend {
             Thread.currentThread().setContextClassLoader(
                 getClass().getClassLoader());
 
-            asyncWriteExecuter.execute(new Runnable() {
+            getAsyncWriteExecutor().execute(new Runnable() {
                 @Override
                 public void run() {
                     try {
@@ -356,7 +366,7 @@ public class S3Backend implements Backend {
                 LOG.debug("[{}] touched. time taken [{}] ms ", new Object[] {
                     identifier, (System.currentTimeMillis() - start) });
             } else {
-                LOG.debug("[{}] touch not required. time taken [{}] ms ",
+                LOG.trace("[{}] touch not required. time taken [{}] ms ",
                     new Object[] { identifier,
                         (System.currentTimeMillis() - start) });
             }
@@ -381,7 +391,8 @@ public class S3Backend implements Backend {
             Thread.currentThread().setContextClassLoader(
                 getClass().getClassLoader());
             S3Object object = s3service.getObject(bucket, key);
-            InputStream in = object.getObjectContent();
+            S3ObjectInputStream s3in = object.getObjectContent();
+            InputStream in = new S3BackendResourceAbortableInputStream(s3in);
             LOG.debug("[{}] read took [{}]ms", identifier,
                 (System.currentTimeMillis() - start));
             return in;
@@ -523,13 +534,13 @@ public class S3Backend implements Backend {
                     long lastModified = s3ObjSumm.getLastModified().getTime();
                     LOG.debug("Identifier [{}]'s lastModified = [{}]", identifier, lastModified);
                     if (lastModified < min
-                        && store.confirmDelete(identifier)
+                        && getDataStore().confirmDelete(identifier)
                          // confirm once more that record's lastModified < min
                         //  order is important here
                         && s3service.getObjectMetadata(bucket,
                             s3ObjSumm.getKey()).getLastModified().getTime() < min) {
                        
-                        store.deleteFromCache(identifier);
+                        getDataStore().deleteFromCache(identifier);
                         LOG.debug("add id [{}] to delete lists",
                             s3ObjSumm.getKey());
                         deleteList.add(new DeleteObjectsRequest.KeyVersion(
@@ -570,9 +581,9 @@ public class S3Backend implements Backend {
     }
 
     @Override
-    public void close() {
+    public void close() throws DataStoreException {
+        super.close();
         // backend is closing. abort all mulitpart uploads from start.
-        asyncWriteExecuter.shutdownNow();
         if(s3service.doesBucketExist(bucket)) {
             tmx.abortMultipartUploads(bucket, startTime);
         }
