@@ -68,15 +68,15 @@ import javax.sql.DataSource;
  * thread initiates its first run (default = <code>3</code> which means 3:00 at night)</li>
  * <li><code>schemaCheckEnabled</code>:  whether the schema check during initialization is enabled
  * (default = <code>true</code>)</li>
+ * </ul>
  * <p>
  * JNDI can be used to get the connection. In this case, use the javax.naming.InitialContext as the driver,
  * and the JNDI name as the URL. If the user and password are configured in the JNDI resource,
  * they should not be configured here. Example JNDI settings:
  * <pre>
- * &lt;param name="driver" value="javax.naming.InitialContext" />
- * &lt;param name="url" value="java:comp/env/jdbc/Test" />
- * </pre> *
- * </ul>
+ * &lt;param name="driver" value="javax.naming.InitialContext" /&gt;
+ * &lt;param name="url" value="java:comp/env/jdbc/Test" /&gt;
+ * </pre>
  */
 public class DatabaseJournal extends AbstractJournal implements DatabaseAware {
 
@@ -304,7 +304,7 @@ public class DatabaseJournal extends AbstractJournal implements DatabaseAware {
     /**
      * This method is called from {@link #init(String, NamespaceResolver)} after the
      * {@link #createConnectionHelper(DataSource)} method, and returns a default {@link CheckSchemaOperation}.
-     * Subclasses can overrride this implementation to get a customized implementation.
+     * Subclasses can override this implementation to get a customized implementation.
      *
      * @return a new {@link CheckSchemaOperation} instance
      */
@@ -321,7 +321,6 @@ public class DatabaseJournal extends AbstractJournal implements DatabaseAware {
      * database type. Should be overridden by subclasses that use a different way to
      * create a connection and therefore require other arguments.
      *
-     * @see #getConnection()
      * @throws JournalException if initialization fails
      */
     protected void init() throws JournalException {
@@ -496,6 +495,7 @@ public class DatabaseJournal extends AbstractJournal implements DatabaseAware {
         } finally {
             DbUtility.close(rs);
             if (!succeeded) {
+                log.debug("doLock.doUnlock(false)");
                 doUnlock(false);
             }
         }
@@ -517,7 +517,7 @@ public class DatabaseJournal extends AbstractJournal implements DatabaseAware {
     private void endBatch(boolean successful) {
         if (--lockLevel == 0) {
             try {
-                conHelper.endBatch(successful);;
+                conHelper.endBatch(successful);
             } catch (SQLException e) {
                 log.error("failed to end batch", e);
             }
