@@ -29,6 +29,7 @@ import javax.jcr.ItemNotFoundException;
 import javax.jcr.PropertyIterator;
 import javax.jcr.Value;
 import javax.jcr.PropertyType;
+import javax.jcr.Repository;
 import javax.jcr.lock.LockException;
 import javax.jcr.lock.LockManager;
 
@@ -296,6 +297,8 @@ public class VersionTest extends AbstractVersionTest {
             version.getLock();
             fail("Version should not be lockable: Version.getLock() did not throw a LockException");
         } catch (LockException success) {
+        } catch (UnsupportedRepositoryOperationException maybe) {
+            assertFalse(isSupported(Repository.OPTION_LOCKING_SUPPORTED));
         }
     }
 
@@ -304,6 +307,7 @@ public class VersionTest extends AbstractVersionTest {
      * javax.jcr.lock.LockException}
      */
     public void testGetLockJcr2() throws Exception {
+        ensureLockingSupported();
         try {
             version.getSession().getWorkspace().getLockManager().getLock(version.getPath());
             fail("Version should not be lockable: Version.getLock() did not throw a LockException");
@@ -482,6 +486,7 @@ public class VersionTest extends AbstractVersionTest {
      * Tests if <code>Version.holdsLock()</code> returns <code>false</code>
      */
     public void testHoldsLock() throws Exception {
+        ensureLockingSupported();
         assertFalse("Version.holdsLock() did not return false", version.holdsLock());
     }
 
@@ -489,6 +494,7 @@ public class VersionTest extends AbstractVersionTest {
      * Tests if <code>Version.holdsLock()</code> returns <code>false</code>
      */
     public void testHoldsLockJcr2() throws Exception {
+        ensureLockingSupported();
         assertFalse("Version.holdsLock() did not return false", version.getSession().getWorkspace().getLockManager().holdsLock(version.getPath()));
     }
 
@@ -517,6 +523,7 @@ public class VersionTest extends AbstractVersionTest {
      * Tests if <code>Version.isLocked()</code> returns <code>false</code>
      */
     public void testIsLockedJcr2() throws Exception {
+        ensureLockingSupported();
         assertFalse("Version.isLocked() did not return false", version.getSession().getWorkspace().getLockManager().isLocked(version.getPath()));
     }
 
@@ -570,6 +577,7 @@ public class VersionTest extends AbstractVersionTest {
      * LockException}
      */
     public void testLock() throws Exception {
+        ensureLockingSupported();
         try {
             version.lock(true, true);
             fail("Version should not be lockable: Version.lock(true,true) did not throw a LockException");
@@ -597,6 +605,7 @@ public class VersionTest extends AbstractVersionTest {
      * LockException}
      */
     public void testLockJcr2() throws Exception {
+        ensureLockingSupported();
         LockManager lockManager = version.getSession().getWorkspace().getLockManager();
         String path = version.getPath();
         try {
@@ -884,6 +893,8 @@ public class VersionTest extends AbstractVersionTest {
             version.unlock();
             fail("Version should not be lockable: Version.unlock() did not throw a LockException");
         } catch (LockException success) {
+        } catch (UnsupportedRepositoryOperationException maybe) {
+            assertFalse(isSupported(Repository.OPTION_LOCKING_SUPPORTED));
         }
     }
 
@@ -892,6 +903,7 @@ public class VersionTest extends AbstractVersionTest {
      * javax.jcr.lock.LockException}
      */
     public void testUnlockJcr2() throws Exception {
+        ensureLockingSupported();
         try {
             version.getSession().getWorkspace().getLockManager().unlock(version.getPath());
             fail("Version should not be lockable: Version.unlock() did not throw a LockException");
