@@ -50,7 +50,8 @@ import javax.xml.parsers.ParserConfigurationException;
 import javax.xml.parsers.SAXParser;
 import javax.xml.parsers.SAXParserFactory;
 
-import org.apache.commons.collections.map.ReferenceMap;
+import org.apache.commons.collections4.map.AbstractReferenceMap.ReferenceStrength;
+import org.apache.commons.collections4.map.ReferenceMap;
 import org.apache.jackrabbit.commons.AbstractSession;
 import org.apache.jackrabbit.jcr2spi.config.CacheBehaviour;
 import org.apache.jackrabbit.jcr2spi.config.RepositoryConfig;
@@ -122,8 +123,8 @@ public class SessionImpl extends AbstractSession
     /**
      * Listeners (weak references)
      */
-    @SuppressWarnings("unchecked")
-    private final Map<SessionListener, SessionListener> listeners = new ReferenceMap(ReferenceMap.WEAK, ReferenceMap.WEAK);
+    private final Map<SessionListener, SessionListener> listeners = new ReferenceMap<>(ReferenceStrength.WEAK,
+            ReferenceStrength.WEAK);
 
     private final Repository repository;
     private final RepositoryConfig config;
